@@ -1,8 +1,7 @@
 from matplotlib import pyplot as plt
 
-from examples.datasets.linear import LinearRegressionDataset, LinearClassificationDataset
-from pytolemaic.pytrust import PyTrust
-from pytolemaic.utils.dmd import DMD
+from pytolemaic import PyTrust
+from resources.datasets.linear import LinearRegressionDataset, LinearClassificationDataset
 
 
 def run():
@@ -19,13 +18,11 @@ def run():
         estimator = dataset.get_model()
 
         # set the feature names names
-        columns_meta = {DMD.FEATURE_NAMES: columns_names}
-
         pytrust = PyTrust(
             model=estimator,
             xtrain=xtrain, ytrain=ytrain,
             xtest=xtest, ytest=ytest,
-            columns_meta=columns_meta)
+            feature_names=columns_names)
 
         sample = xtest[0, :]
 
