@@ -11,7 +11,7 @@ from pytolemaic.analysis_logic.model_analysis.sensitivity.sensitivity import \
     SensitivityAnalysis
 from pytolemaic.analysis_logic.model_analysis.sensitivity.sensitivity_reports import SensitivityFullReport
 from pytolemaic.analysis_logic.prediction_analysis.lime_report import LimeExplainer
-from pytolemaic.dataset_quality_report import TestSetQualityReport, TrainSetQualityReport, QualityReport, \
+from pytolemaic.analysis_logic.quality_report import TestSetQualityReport, TrainSetQualityReport, QualityReport, \
     ModelQualityReport
 from pytolemaic.prediction_uncertainty.uncertainty_model import \
     UncertaintyModelClassifier, UncertaintyModelRegressor, UncertaintyModelBase
@@ -138,7 +138,7 @@ class PyTrust():
         self.sensitivity = SensitivityAnalysis()
 
         self._uncertainty_models = {}
-
+        self.covariance_shift = None
         self._cache = {}
 
     def _validate_input(self):
@@ -244,7 +244,7 @@ class PyTrust():
         return PyTrustReport(pytrust=pytrust)
 
     @classmethod
-    def create_pytrust_for_separability_test(cls, train: DMD, test: DMD, **pytrust_kwargs):
+    def create_pytrust_for_separability_test(cls, train: DMD, test: DMD, covariance_shift=None, **pytrust_kwargs):
         """
         Create scoring report
         Args:
@@ -255,8 +255,8 @@ class PyTrust():
             separability pytrust
         """
 
-        covariance_shift = CovarianceShift()
-        covariance_shift.calc_separation_quality(dmd_train=train, dmd_test=test)
+        covariance_shift = covariance_shift or CovarianceShift()
+        covariance_shift.calc_covariance_shift(dmd_train=train, dmd_test=test)
 
         separability_pytrust = PyTrust(model=covariance_shift.classifier,
                                        xtrain=covariance_shift.train,
@@ -293,8 +293,9 @@ class PyTrust():
         return self.create_pytrust_report(pytrust=self)
 
     def _create_pytrust_for_separability_test(self):
+        self.covariance_shift = CovarianceShift()
         return self.create_pytrust_for_separability_test(
-            train=self.train, test=self.test, metric=self.metric)
+            train=self.train, test=self.test, metric=self.metric, covariance_shift=self.covariance_shift)
 
     # endregion
 
@@ -304,15 +305,11 @@ class PyTrust():
         if method not in self._uncertainty_models:
 
             if self.is_classification:
-                method = 'confidence' if method == 'default' else method
                 uncertainty_model = UncertaintyModelClassifier(
-                    model=self.model,
-                    uncertainty_method=method)
+                    model=self.model, uncertainty_method=method)
             else:
-                method = 'mae' if method == 'default' else method
                 uncertainty_model = UncertaintyModelRegressor(
-                    model=self.model,
-                    uncertainty_method=method)
+                    model=self.model, uncertainty_method=method)
 
             uncertainty_model.fit(dmd_test=self.test)
             self._uncertainty_models[method] = uncertainty_model
